==> nextcloud-jitsi-v0.18.0.tar.gz: jitsi/l10n/gl.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "conferencias",
    "Jitsi Integration" : "Integración de Jitsi",
    "Conferences" : "Conferencias",
    "Jitsi Integration (unofficial)" : "Integración de Jitsi (non oficial)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "Esta aplicación integra as conferencias Jitsi en Nextcloud.\n\nCaracterísticas:\n- 🎥 Conferencias sinxelas en liña en Nextcloud empregando Jitsi\n- 🔗 Ligazóns para salas de conferencias compartíbeis\n- 🔎 Amosa as salas de conferencias na busca global\n- ✅ Probe do sistema antes de unirse a unha conferencia\n\nLea a [documentación](https://github.com/nextcloud/jitsi).",
    "Loading …" : "Cargando…",
    "Server URL (required)" : "URL do servidor (necesario)",
    "Help link (optional)" : "Ligazón de axuda (opcional)",
    "Display \"Join using the Jitsi app\"" : "Amosar «Únase empregando a aplicación Jitsi»",
    "JWT Secret (optional)" : "Segredo JWT (opcional)",
    "JWT App ID" : "ID da aplicación JWT",
    "JWT Audience (optional)" : "Audiencia JWT (opcional)",
    "JWT Issuer (optional)" : "Emisor JWT (opcional)",
    "save" : "gardar",
    "saved" : "gardado",
    "Saving …" : "Gardando…",
    "Please provide a Jitsi instance URL" : "Forneza un URL dunha instancia de Jitsi",
    "The server URL must start with https://" : "O URL do servidor debe comezar por https://",
    "It is highly recommended to set up a dedicated Jitsi instance" : "É moi recomendábel estabelecer unha instancia Jitsi dedicada",
    "Please provide the App ID" : "Forneza o ID da aplicación",
    "Failed to save settings" : "Produciuse un fallo ao gardar os axustes",
    "Failed to load settings" : "Produciuse un fallo ao cargar os axustes",
    "Conference rooms" : " Salas de conferencias",
    "Conference" : "Conferencia",
    "Conference left" : " Conferencia abandonada",
    "Problems detected" : "Problemas detectados",
    "Your browser is non-optimal:" : "O seu navegador non é óptimo:",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "A calidade do son e do vídeo pode ser deficiente. Recoméndase utilizar unha versión recente de <b>Firefox/Chrome/Chromium</b>.",
    "Browser not supported" : "Este navegador non é compatíbel",
    "Show system check" : "Amosar a comprobación do sistema",
    "Your name:" : "O seu nome:",
    "Click here to join" : "Prema aquí para unirse",
    "Start muted" : "Comezar silenciado",
    "Start with camera off" : "Comezar coa cámara apagada",
    "Join with desktop app" : "Unirse coa aplicación de escritorio",
    "Join with mobile app" : "Unirse coa aplicación móbil",
    "App button not working?" : "Non funciona o botón da aplicación?",
    "Download the desktop app here ↗" : "Descargue a aplicación de escritorio aquí ↗",
    "The mobile app is available via the app store of your choice." : "A aplicación móbil está dispoñíbel na tenda de aplicacións da súa escolla.",
    "After successful installation try the button again." : "Após unha instalación satisfactoria, probe o botón de novo.",
    "Still not working? Copy the link below and paste it into the input field on the Jitsi App start screen." : "Aínda non funciona? Copie a seguinte ligazón e péguea no campo de entrada da pantalla de inicio da aplicación Jitsi.",
    "Link copied" : "Ligazón copiada",
    "Cannot copy, please copy the link manually" : "Non foi posíbel copiala. Copie a ligazón manualmente",
    "Copy to clipboard" : "Copiar no portapapeis.",
    "Browser" : "Navegador",
    "non-optimal" : "non óptimo",
    "not supported" : "non admitido",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "A calidade do son e do vídeo pode ser deficiente.<br> Recoméndase utilizar unha versión recente de <b>Firefox/Chrome/Chromium</b>.",
    "Help" : "Axuda",
    "Camera" : "Cámara",
    "Name of the new room" : "Nome da nova sala",
    "No conference rooms yet" : "Aínda non hai salas de conferencias",
    "Create the first room:" : "Crear a primeira sala:",
    "Microphone" : "Micrófono",
    "Join" : "Unirse",
    "Delete room" : "Eliminar a sala",
    "Room not found" : "Non se atopou a sala",
    "Please check the link/URL and ask your host" : "Comprobe a ligazón/URL e pregúntelle ao seu anfitrión",
    "Audio output" : "Saída de son",
    "Play test sound" : "Reproducir o son de proba",
    "System check" : "Comprobación do sistema",
    "Got issues?" : "Ten problemas?",
    "Known problems / what you can try" : "Problemas coñecidos / que pode probar",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• Acepte os permisos de acceso ao micrófono/cámara na parte superior da pantalla",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• Comprobe os permisos de acceso ao micrófono/cámara premendoc na icona situada a carón da barra de enderezos. A seguir, recargue a páxina.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• Se ten DroidCam: Conéctese á cámara do móbil e volva cargar a páxina",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• Probe a unirse coa aplicación Jitsi (siga as instrucións da parte inferior da páxina)",
    "No camera/microphone access" : "Sen acceso á cámara/micrófono",
    "Review your browser camera and microphone access settings" : "Revisa os axustes de acceso á cámara e ao micrófono do seu navegador",
    "Click here for {browser} instructions" : "Prema aquí para ver as instrucións para {browser}",
    "Does not work?" : "Non funciona?",
    "Click here for troubleshooting help" : "Prema aquí para obter axuda para solucionar problemas",
    "Conferences app not yet configured" : "A aplicación de conferencias aínda non está configurada",
    "Please contact your administrator to set up the conferences app." : "Póñase en contacto coa administración desta instancia para estabelecer a aplicación de conferencias.",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "O seu navegador (%1$s) está desactualizado e <br>xa non é compatíbel",
    "It is recommended to use the latest version of one of the following browsers:" : "Recoméndase usar a última versión dun dos seguintes navegadores:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-jitsi-v0.19.0.tar.gz: jitsi/l10n/gl.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "conferencias",
    "Jitsi Integration" : "Integración de Jitsi",
    "Conferences" : "Conferencias",
    "Jitsi Integration (unofficial)" : "Integración de Jitsi (non oficial)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "Esta aplicación integra as conferencias Jitsi en Nextcloud.\n\nCaracterísticas:\n- 🎥 Conferencias sinxelas en liña en Nextcloud empregando Jitsi\n- 🔗 Ligazóns para salas de conferencias compartíbeis\n- 🔎 Amosa as salas de conferencias na busca global\n- ✅ Probe do sistema antes de unirse a unha conferencia\n\nLea a [documentación](https://github.com/nextcloud/jitsi).",
    "Loading …" : "Cargando…",
    "Server URL (required)" : "URL do servidor (necesario)",
    "Help link (optional)" : "Ligazón de axuda (opcional)",
    "Display \"Join using the Jitsi app\"" : "Amosar «Únase empregando a aplicación Jitsi»",
    "JWT Secret (optional)" : "Segredo JWT (opcional)",
    "JWT App ID" : "ID da aplicación JWT",
    "JWT Audience (optional)" : "Audiencia JWT (opcional)",
    "JWT Issuer (optional)" : "Emisor JWT (opcional)",
    "save" : "gardar",
    "saved" : "gardado",
    "Saving …" : "Gardando…",
    "Please provide a Jitsi instance URL" : "Forneza un URL dunha instancia de Jitsi",
    "The server URL must start with https://" : "O URL do servidor debe comezar por https://",
    "It is highly recommended to set up a dedicated Jitsi instance" : "É moi recomendábel definir unha instancia Jitsi específica",
    "Please provide the App ID" : "Forneza o ID da aplicación",
    "Failed to save settings" : "Produciuse un fallo ao gardar os axustes",
    "Failed to load settings" : "Produciuse un fallo ao cargar os axustes",
    "Conference rooms" : " Salas de conferencias",
    "Conference" : "Conferencia",
    "Conference left" : " Conferencia abandonada",
    "Problems detected" : "Problemas detectados",
    "Your browser is non-optimal:" : "O seu navegador non é óptimo:",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "A calidade do son e do vídeo pode ser deficiente. Recoméndase utilizar unha versión recente de <b>Firefox/Chrome/Chromium</b>.",
    "Browser not supported" : "Este navegador non é compatíbel",
    "Show system check" : "Amosar a comprobación do sistema",
    "Your name:" : "O seu nome:",
    "Click here to join" : "Prema aquí para unirse",
    "Start muted" : "Comezar enmudecido",
    "Start with camera off" : "Comezar coa cámara apagada",
    "Join with desktop app" : "Unirse coa aplicación de escritorio",
    "Join with mobile app" : "Unirse coa aplicación móbil",
    "App button not working?" : "Non funciona o botón da aplicación?",
    "Download the desktop app here ↗" : "Descargue a aplicación de escritorio aquí ↗",
    "The mobile app is available via the app store of your choice." : "A aplicación móbil está dispoñíbel na tenda de aplicacións da súa escolla.",
    "After successful installation try the button again." : "Após unha instalación satisfactoria, probe o botón de novo.",
    "Still not working? Copy the link below and paste it into the input field on the Jitsi App start screen." : "Aínda non funciona? Copie a seguinte ligazón e péguea no campo de entrada da pantalla de inicio da aplicación Jitsi.",
    "Link copied" : "Ligazón copiada",
    "Cannot copy, please copy the link manually" : "Non foi posíbel copiala. Copie a ligazón manualmente",
    "Copy to clipboard" : "Copiar no portapapeis.",
    "Browser" : "Navegador",
    "non-optimal" : "non óptimo",
    "not supported" : "non admitido",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "A calidade do son e do vídeo pode ser deficiente.<br> Recoméndase utilizar unha versión recente de <b>Firefox/Chrome/Chromium</b>.",
    "Help" : "Axuda",
    "Camera" : "Cámara",
    "Name of the new room" : "Nome da nova sala",
    "No conference rooms yet" : "Aínda non hai salas de conferencias",
    "Create the first room:" : "Crear a primeira sala:",
    "Microphone" : "Micrófono",
    "Join" : "Unirse",
    "Delete room" : "Eliminar a sala",
    "Room not found" : "Non se atopou a sala",
    "Please check the link/URL and ask your host" : "Comprobe a ligazón/URL e pregúntelle ao seu anfitrión",
    "Audio output" : "Saída de son",
    "Play test sound" : "Reproducir o son de proba",
    "System check" : "Comprobación do sistema",
    "Got issues?" : "Ten problemas?",
    "Known problems / what you can try" : "Problemas coñecidos / que pode probar",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• Acepte os permisos de acceso ao micrófono/cámara na parte superior da pantalla",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• Comprobe os permisos de acceso ao micrófono/cámara premendoc na icona situada a carón da barra de enderezos. A seguir, recargue a páxina.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• Se ten DroidCam: Conéctese á cámara do móbil e volva cargar a páxina",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• Probe a unirse coa aplicación Jitsi (siga as instrucións da parte inferior da páxina)",
    "No camera/microphone access" : "Sen acceso á cámara/micrófono",
    "Review your browser camera and microphone access settings" : "Revisa os axustes de acceso á cámara e ao micrófono do seu navegador",
    "Click here for {browser} instructions" : "Prema aquí para ver as instrucións para {browser}",
    "Does not work?" : "Non funciona?",
    "Click here for troubleshooting help" : "Prema aquí para obter axuda para solucionar problemas",
    "Conferences app not yet configured" : "A aplicación de conferencias aínda non está configurada",
    "Please contact your administrator to set up the conferences app." : "Póñase en contacto coa administración desta instancia para definir a aplicación de conferencias.",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "O seu navegador (%1$s) está desactualizado e <br>xa non é compatíbel",
    "It is recommended to use the latest version of one of the following browsers:" : "Recoméndase usar a última versión dun dos seguintes navegadores:"
},
"nplurals=2; plural=(n != 1);");
